// This file is part of Pushup Buddy.
// Copyright 2010 Fredrik Portstrom
//
// Pushup Buddy is free software: you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation, either version 3 of the
// License, or (at your option) any later version.
//
// Pushup Buddy is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Pushup Buddy. If not, see
// <http://www.gnu.org/licenses/>.

package org.example.pushupbuddy;

import android.app.ListActivity;
import android.os.Bundle;
import android.view.ContextMenu;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.TextView;

public class BaseWorkoutActivity extends ListActivity {
    long workoutId = -1;
    private ArrayAdapter<Set> mListAdapter;
    private TextView mSetCountView;
    private TextView mPushupCountView;
    private TextView mTimeElapsedView;
    private TextView mSecondsPerPushupView;
    private Workout mWorkout;

    static String formatTime(long time) {
	time = (time + 500) / 1000;
	return time < 3600 ? String.format("%d:%02d", time / 60, time % 60) : String.format("%d:%02d:%02d", time / 3600, time / 60 % 60, time % 60);
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
	mSetCountView = (TextView)findViewById(R.id.set_count);
	mPushupCountView = (TextView)findViewById(R.id.pushup_count);
	mTimeElapsedView = (TextView)findViewById(R.id.time_elapsed);
	mSecondsPerPushupView = (TextView)findViewById(R.id.seconds_per_pushup);
	mListAdapter = new ArrayAdapter<Set>(this, 0) {
	    public View getView(int position, View convertView, ViewGroup parent) {
		if (convertView == null) {
		    convertView = getLayoutInflater().inflate(R.layout.set, parent, false);
		}

		Set set = getItem(position);
		long timeElapsed = set.endTime - set.startTime;
		((TextView)convertView.findViewById(R.id.set_number)).setText("" + (position + 1));
		((TextView)convertView.findViewById(R.id.pushup_count)).setText("" + set.pushupCount);
		((TextView)convertView.findViewById(R.id.start_time)).setText(formatTime(set.startTime));
		((TextView)convertView.findViewById(R.id.time_elapsed)).setText(formatTime(timeElapsed));
		((TextView)convertView.findViewById(R.id.seconds_per_pushup)).setText(String.format("%.1f", .001 * timeElapsed / set.pushupCount));
		return convertView;
	    }
	};
	setListAdapter(mListAdapter);
	registerForContextMenu(getListView());
    }

    @Override
    public void onCreateContextMenu(ContextMenu menu, View v, ContextMenu.ContextMenuInfo menuInfo) {
	getMenuInflater().inflate(R.menu.set, menu);
    }

    @Override
    public boolean onContextItemSelected(MenuItem item) {
	int index = (int)((AdapterView.AdapterContextMenuInfo)item.getMenuInfo()).position;
	Set set = mWorkout.sets.get(index);

	if (item.getItemId() == R.id.increment) {
	    mWorkout.pushupCount++;
	    set.pushupCount++;
	} else {
	    mWorkout.pushupCount--;
	    if (set.pushupCount > 1) {
		set.pushupCount--;
	    } else {
		if (mWorkout.setCount < 2) {
		    if (workoutId >= 0) {
			removeWorkout();
		    }
		    return true;
		}
		mWorkout.setCount--;
		mWorkout.sets.remove(index);
	    }
	}

	if (workoutId > 0) {
	    Database database = new Database(this);
	    database.exec("UPDATE workouts SET pushup_count = ?, set_count = ?, time_elapsed = ?, data = ? WHERE _id = ?", new Object[] { mWorkout.pushupCount, mWorkout.setCount, mWorkout.sets.get(mWorkout.setCount - 1).endTime, mWorkout.serialize(), workoutId });
	    database.close();
	}

	update(mWorkout);
	return true;
    }

    void update(Workout workout) {
	mWorkout = workout;
	mSetCountView.setText("" + workout.setCount);
	mPushupCountView.setText("" + workout.pushupCount);
	mTimeElapsedView.setText(formatTime(workout.timeElapsed));
	mSecondsPerPushupView.setText(workout.pushupCount > 0 ? String.format("%.1f", .001 * workout.timeElapsed / workout.pushupCount) : "-");
	mListAdapter.setNotifyOnChange(false);
	mListAdapter.clear();
	for (Set set : workout.sets) {
	    mListAdapter.add(set);
	}
	mListAdapter.notifyDataSetChanged();
    }

    protected void removeWorkout() {
	Database database = new Database(this);
	database.exec("DELETE FROM workouts WHERE _id = ?", new Object[] { workoutId });
	database.close();
	finish();
    }
}
