// This file is part of Pushup Buddy.
// Copyright 2010 Fredrik Portstrom
//
// Pushup Buddy is free software: you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation, either version 3 of the
// License, or (at your option) any later version.
//
// Pushup Buddy is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Pushup Buddy. If not, see
// <http://www.gnu.org/licenses/>.

package org.example.pushupbuddy;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.content.Intent;
import android.database.Cursor;
import android.net.Uri;
import android.os.Bundle;
import android.os.Environment;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Date;

public class ExportCsvActivity extends Activity {
    @Override
    public void onCreate(Bundle savedInstanceState) {
	super.onCreate(savedInstanceState);
	setContentView(R.layout.csv);
	Button button = (Button)findViewById(R.id.button);
	button.setText("Export");
	button.setOnClickListener(new View.OnClickListener() {
		public void onClick(View view) {
		    exportCsv();
		}
	    });

	if (savedInstanceState == null) {
	    ((EditText)findViewById(R.id.input)).setText(new File(Environment.getExternalStorageDirectory(), "pushup_workout_log.csv").toString());
	}
    }

    @Override
    protected Dialog onCreateDialog(int id) {
	AlertDialog.Builder builder = new AlertDialog.Builder(this);
	builder.setMessage("Failed to create or write to file");
	builder.setNeutralButton("Close", null);
	return builder.create();
    }

    private void exportCsv() {
	File file = new File(((EditText)findViewById(R.id.input)).getText().toString());
	SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
	Database database = new Database(this);
	Cursor cursor = database.query("SELECT created_at, data FROM workouts ORDER BY _id");

	try {
	    BufferedWriter writer = new BufferedWriter(new FileWriter(file));

	    while (cursor.moveToNext()) {
		writer.write(format.format(new Date(1000L * cursor.getInt(0))) + "," + cursor.getString(1));
		writer.newLine();
	    }

	    writer.close();
	} catch (IOException e) {
	    showDialog(0);
	} finally {
	    cursor.close();
	    database.close();
	}

	finish();
	Toast.makeText(this, "Exported to " + file, Toast.LENGTH_SHORT).show();
	Intent intent = new Intent(Intent.ACTION_SEND);
	intent.setType("text/csv");
	intent.putExtra(Intent.EXTRA_STREAM, Uri.fromFile(file));
	startActivity(Intent.createChooser(intent, "Share file"));
    }
}
