// This file is part of Pushup Buddy.
// Copyright 2010 Fredrik Portstrom
//
// Pushup Buddy is free software: you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation, either version 3 of the
// License, or (at your option) any later version.
//
// Pushup Buddy is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Pushup Buddy. If not, see
// <http://www.gnu.org/licenses/>.

package org.example.pushupbuddy;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.os.Bundle;
import android.os.Environment;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class ImportCsvActivity extends Activity {
    @Override
    public void onCreate(Bundle savedInstanceState) {
	super.onCreate(savedInstanceState);
	setContentView(R.layout.csv);
	Button button = (Button)findViewById(R.id.button);
	button.setText("Import");
	button.setOnClickListener(new View.OnClickListener() {
		public void onClick(View view) {
		    importCsv();
		}
	    });

	if (savedInstanceState == null) {
	    ((EditText)findViewById(R.id.input)).setText(new File(Environment.getExternalStorageDirectory(), "pushup_workout_log.csv").toString());
	}
    }

    @Override
    protected Dialog onCreateDialog(int id) {
	AlertDialog.Builder builder = new AlertDialog.Builder(this);
	builder.setMessage(id < 1 ? "File not found" : id < 2 ? "Failed to open or read from file" : "Invalid file format");
	builder.setNeutralButton("Close", null);
	return builder.create();
    }

    private void importCsv() {
	File file = new File(((EditText)findViewById(R.id.input)).getText().toString());
	Database database = new Database(this);
	database.beginTransaction();

	try {
	    BufferedReader reader = new BufferedReader(new FileReader(file));
	    SimpleDateFormat format1 = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
	    SimpleDateFormat format2 = new SimpleDateFormat("yyyy-MM-dd");
	    Pattern pattern = Pattern.compile("^\\s*([^,;]+)\\s*[,;]\\s*([^,;]+)\\s*([,;].*|$)");

	    for (;;) {
		String line = reader.readLine();

		if (line == null) {
		    break;
		}

		Matcher matcher = pattern.matcher(line);

		if (!matcher.matches()) {
		    reader.close();
		    showDialog(2);
		    return;
		}

		Date date;
		String dateString = matcher.group(1);

		try {
		    date = format1.parse(dateString);
		} catch (ParseException e1) {
		    try {
			date = format2.parse(dateString);
		    } catch (ParseException e2) {
			showDialog(2);
			return;
		    }
		}

		Workout workout = new Workout();

		try {
		    workout.unserialize(matcher.group(2));
		} catch (NumberFormatException e) {
		    showDialog(2);
		    return;
		}

		database.exec("INSERT INTO workouts (created_at, pushup_count, set_count, time_elapsed, data) VALUES (?, ?, ?, ?, ?)", new Object[] { (int)(date.getTime() / 1000), workout.pushupCount, workout.setCount, workout.timeElapsed, workout.serialize() });
	    }

	    reader.close();
	    database.setTransactionSuccessful();
	    finish();
	    Toast.makeText(this, "Imported from " + file, Toast.LENGTH_SHORT).show();
	} catch (FileNotFoundException e) {
	    showDialog(0);
	} catch (IOException e) {
	    showDialog(1);
	} finally {
	    database.endTransaction();
	    database.close();
	}
    }
}
