// This file is part of Pushup Buddy.
// Copyright 2010 Fredrik Portstrom
//
// Pushup Buddy is free software: you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation, either version 3 of the
// License, or (at your option) any later version.
//
// Pushup Buddy is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Pushup Buddy. If not, see
// <http://www.gnu.org/licenses/>.

package org.example.pushupbuddy;

import android.app.AlertDialog;
import android.app.Dialog;
import android.content.ComponentName;
import android.content.Intent;
import android.content.ServiceConnection;
import android.content.SharedPreferences;
import android.hardware.Sensor;
import android.hardware.SensorManager;
import android.media.AudioManager;
import android.os.Bundle;
import android.os.IBinder;
import android.preference.PreferenceManager;
import android.text.Html;
import android.text.method.LinkMovementMethod;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;

public class MainActivity extends BaseWorkoutActivity {
    private boolean mBound;
    private Button mButton;
    private MainService mMainService;
    private MenuCommands mMenuCommands = new MenuCommands(this);

    @Override
    public void onCreate(Bundle savedInstanceState) {
        setContentView(R.layout.main);
        super.onCreate(savedInstanceState);
	TextView textView = (TextView)findViewById(android.R.id.empty);
	textView.setMovementMethod(LinkMovementMethod.getInstance());
	textView.setText(Html.fromHtml("To start a new workout, press the Start button and place this device under any of your legs, so your pushups are detected by the proximity sensor without problem when you do them in good form. <a href=http://fredrik.jemla.eu/pushupbuddy>More advice</a>"));
	mButton = (Button)findViewById(R.id.button);
	mButton.setOnClickListener(new View.OnClickListener() {
		public void onClick(View view) {
		    if (mMainService != null) {
			stopService(new Intent(MainActivity.this, MainService.class));
			unbindService(mServiceConnection);
			mBound = false;
			mMainService = null;
			mButton.setText("Start");
		    } else {
			if (((SensorManager)getSystemService(SENSOR_SERVICE)).getSensorList(Sensor.TYPE_PROXIMITY).isEmpty()) {
			    showDialog(0);
			    return;
			}

			if (mBound) {
			    unbindService(mServiceConnection);
			}

			workoutId = -1;
			startService(new Intent(MainActivity.this, MainService.class));
			mBound = bindService(new Intent(MainActivity.this, MainService.class), mServiceConnection, 0);
		    }
		}
	    });
	((Button)findViewById(R.id.workout_list_button)).setOnClickListener(new View.OnClickListener() {
		public void onClick(View view) {
		    startActivity(new Intent(MainActivity.this, WorkoutListActivity.class));
		}
	    });
    }

    @Override
    public void onStart() {
	super.onResume();
	mButton.setText("Start");
	mBound = bindService(new Intent(this, MainService.class), mServiceConnection, 0);
	SharedPreferences preferences = PreferenceManager.getDefaultSharedPreferences(this);
	setVolumeControlStream(preferences.getBoolean("count_loud", true) || preferences.getBoolean("tell_progress", true) || preferences.getBoolean("rest_reminder", true) || preferences.getBoolean("overdue_reminder", true) ? AudioManager.STREAM_MUSIC : AudioManager.USE_DEFAULT_STREAM_TYPE);
    }

    @Override
    public void onStop() {
	super.onStop();

	if (mBound) {
	    unbindService(mServiceConnection);
	}
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
	getMenuInflater().inflate(R.menu.main, menu);
	return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
	return mMenuCommands.onOptionsItemSelected(item.getItemId());
    }

    @Override
    protected Dialog onCreateDialog(int id) {
	if (id > 0) {
	    return mMenuCommands.onCreateDialog(id);
	}

	AlertDialog.Builder builder = new AlertDialog.Builder(this);
	builder.setMessage("Your device doesn't have a proximity sensor and can't detect pushups.");
	builder.setNeutralButton("Close", null);
	return builder.create();
    }

    private ServiceConnection mServiceConnection = new ServiceConnection() {
	    public void onServiceConnected(ComponentName name, IBinder service) {
		mMainService = ((MainService.LocalBinder) service).getService();
		mMainService.mainActivity = MainActivity.this;
		mButton.setText("Stop");

		if (mMainService.workout != null) {
		    update(mMainService.workout);
		}
	    }

	    public void onServiceDisconnected(ComponentName name) {
		mMainService = null;
	    }
	};
}
