// This file is part of Pushup Buddy.
// Copyright 2010 Fredrik Portstrom
//
// Pushup Buddy is free software: you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation, either version 3 of the
// License, or (at your option) any later version.
//
// Pushup Buddy is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Pushup Buddy. If not, see
// <http://www.gnu.org/licenses/>.

package org.example.pushupbuddy;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.database.Cursor;
import android.os.Environment;
import android.widget.Toast;

public class MenuCommands {
    private Activity mActivity;

    public MenuCommands(Activity activity) {
	mActivity = activity;
    }

    public boolean onOptionsItemSelected(int id) {
	if (id == R.id.preferences) {
	    mActivity.startActivity(new Intent(mActivity, PreferencesActivity.class));
	} else if (id == R.id.import_csv) {
	    if(Environment.MEDIA_MOUNTED.equals(Environment.getExternalStorageState())) {
		mActivity.startActivity(new Intent(mActivity, ImportCsvActivity.class));
	    } else {
		mActivity.showDialog(1);
	    }
	} else if (id == R.id.export_csv) {
	    if(Environment.MEDIA_MOUNTED.equals(Environment.getExternalStorageState())) {
		Database database = new Database(mActivity);
		final Cursor cursor = database.query("SELECT 1 FROM workouts LIMIT 1");

		if(cursor.moveToNext()) {
		    mActivity.startActivity(new Intent(mActivity, ExportCsvActivity.class));
		} else {
		    mActivity.showDialog(2);
		}

		cursor.close();
		database.close();
	    } else {
		mActivity.showDialog(1);
	    }
	} else if (id == R.id.count_workouts) {
	    mActivity.showDialog(3);
	} else if (id == R.id.delete_all_workouts) {
	    mActivity.showDialog(4);
	} else {
	    return false;
	}

	return true;
    }

    public Dialog onCreateDialog(int id) {
	return id < 2 ? createMessageDialog("SD card is not available") : id < 3 ? createMessageDialog("There are no workouts to export.") : id < 4 ? createCountDialog() : createDeleteAllDialog();
    }

    private Dialog createMessageDialog(String message) {
	AlertDialog.Builder builder = new AlertDialog.Builder(mActivity);
	builder.setMessage(message);
	builder.setNeutralButton("Close", null);
	return builder.create();
    }

    private Dialog createCountDialog() {
	Database database = new Database(mActivity);
	Cursor cursor = database.query("SELECT COUNT(*) FROM workouts");
	cursor.moveToNext();
	int count = cursor.getInt(0);
	cursor.close();
	database.close();
	AlertDialog.Builder builder = new AlertDialog.Builder(mActivity);
	builder.setMessage(count == 1 ? "1 workout" : "" + count + " workouts");
	builder.setNeutralButton("Close", null);
	Dialog dialog = builder.create();
	dialog.setOnDismissListener(new DialogInterface.OnDismissListener() {
		public void onDismiss(DialogInterface dialog) {
		    mActivity.removeDialog(3);
		}
	    });
	return dialog;
    }

    private Dialog createDeleteAllDialog() {
	AlertDialog.Builder builder = new AlertDialog.Builder(mActivity);
	builder.setMessage("Delete all workouts? This cannot be undone.");
	builder.setPositiveButton("Delete", new DialogInterface.OnClickListener() {
		public void onClick(DialogInterface dialog, int which) {
		    deleteAllWorkouts();
		}
	    });
	builder.setNeutralButton("Cancel", null);
	return builder.create();
    }

    protected void deleteAllWorkouts() {
	Database database = new Database(mActivity);
	database.exec("DELETE FROM workouts");
	database.close();
	Toast.makeText(mActivity, "All workouts are now deleted", Toast.LENGTH_SHORT).show();
    }
}
