// This file is part of Pushup Buddy.
// Copyright 2010 Fredrik Portstrom
//
// Pushup Buddy is free software: you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation, either version 3 of the
// License, or (at your option) any later version.
//
// Pushup Buddy is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Pushup Buddy. If not, see
// <http://www.gnu.org/licenses/>.

package org.example.pushupbuddy;

import java.util.ArrayList;

public class Workout {
    public int setCount;
    public int pushupCount;
    public int timeElapsed;
    public ArrayList<Set> sets;

    public Workout() {
	sets = new ArrayList<Set>();
    }

    public String serialize() {
	StringBuilder stringBuilder = new StringBuilder();
	boolean started = false;
	int lastTime = 0;

	for (Set set : sets) {
	    if (started) {
		stringBuilder.append(" ");
		stringBuilder.append(set.startTime - lastTime);
		stringBuilder.append(" ");
	    }
	    started = true;
	    stringBuilder.append(set.pushupCount);
	    stringBuilder.append(" ");
	    stringBuilder.append(set.endTime - set.startTime);
	    lastTime = set.endTime;
	}

	return stringBuilder.toString();
    }

    public void unserialize(String data) {
	String[] tokens = data.split(" ");
	int i = 0;

	while (i < tokens.length) {
	    setCount++;
	    Set set = new Set();
	    if (i > 0) {
		set.startTime = parseUnsignedInt(tokens[i++]) + timeElapsed;
	    }
	    set.pushupCount = parseUnsignedInt(tokens[i++]);
	    timeElapsed = parseUnsignedInt(tokens[i++]) + set.startTime;
	    set.endTime = timeElapsed;
	    pushupCount += set.pushupCount;
	    sets.add(set);
	}
    }

    private int parseUnsignedInt(String string) {
	int value = Integer.parseInt(string);
	if (value < 0) {
	    throw new NumberFormatException("Unexpected negative number");
	}
	return value;
    }
}
