// This file is part of Pushup Buddy.
// Copyright 2010 Fredrik Portstrom
//
// Pushup Buddy is free software: you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation, either version 3 of the
// License, or (at your option) any later version.
//
// Pushup Buddy is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Pushup Buddy. If not, see
// <http://www.gnu.org/licenses/>.

package org.example.pushupbuddy;

import android.app.Dialog;
import android.app.ListActivity;
import android.content.Context;
import android.content.Intent;
import android.database.Cursor;
import android.os.Bundle;
import android.text.format.DateFormat;
import android.view.ContextMenu;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ListView;
import android.widget.ResourceCursorAdapter;
import android.widget.TextView;
import java.util.Date;

public class WorkoutListActivity extends ListActivity {
    private Database mDatabase;
    private MenuCommands mMenuCommands = new MenuCommands(this) {
	    @Override
	    protected void deleteAllWorkouts() {
		super.deleteAllWorkouts();
		fillData();
	    }
	};

    @Override
    public void onCreate(Bundle savedInstanceState) {
	super.onCreate(savedInstanceState);
	setContentView(R.layout.workout_list);
	registerForContextMenu(getListView());
	mDatabase = new Database(this);
    }

    @Override
    protected void onDestroy() {
	super.onDestroy();
	mDatabase.close();
    }

    @Override
    protected void onResume() {
	super.onResume();
	fillData();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
	getMenuInflater().inflate(R.menu.main, menu);
	return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
	return mMenuCommands.onOptionsItemSelected(item.getItemId());
    }

    @Override
    protected void onListItemClick(ListView l, View v, int position, long id) {
	super.onListItemClick(l, v, position, id);
	Intent intent = new Intent(this, WorkoutActivity.class);
	intent.putExtra("org.example.pushupbuddy.Id", id);
	startActivity(intent);
    }

    @Override
    public void onCreateContextMenu(ContextMenu menu, View v, ContextMenu.ContextMenuInfo menuInfo) {
	getMenuInflater().inflate(R.menu.workout_list_row, menu);
    }

    @Override
    public boolean onContextItemSelected(MenuItem item) {
	long id = ((AdapterView.AdapterContextMenuInfo)item.getMenuInfo()).id;
	if (item.getItemId() == R.id.delete) {
	    mDatabase.exec("DELETE FROM workouts WHERE _id = ?", new Object[] { id });
	    fillData();
	} else {
	    Intent intent = new Intent(this, WorkoutActivity.class);
	    intent.putExtra("org.example.pushupbuddy.Id", id);
	    startActivity(intent);
	}
	return true;
    }

    @Override
    protected Dialog onCreateDialog(int id) {
	return mMenuCommands.onCreateDialog(id);
    }

    private void fillData() {
	Cursor cursor = mDatabase.query("SELECT _id, created_at, pushup_count, set_count, time_elapsed FROM workouts ORDER BY created_at DESC");
	startManagingCursor(cursor);
	setListAdapter(new ResourceCursorAdapter(this, R.layout.workout_list_row, cursor) {
		public void bindView(View view, Context context, Cursor cursor) {
		    Date date = new Date(1000L * cursor.getInt(1));
		    ((TextView)view.findViewById(R.id.created_at)).setText(DateFormat.getDateFormat(context).format(date) + " " + DateFormat.getTimeFormat(context).format(date));
		    ((TextView)view.findViewById(R.id.pushup_count)).setText(cursor.getString(2));
		    ((TextView)view.findViewById(R.id.pushups_label)).setText(cursor.getInt(2) == 1 ? "pushup" : "pushups");
		    ((TextView)view.findViewById(R.id.set_count)).setText(cursor.getString(3));
		    ((TextView)view.findViewById(R.id.time_elapsed)).setText(BaseWorkoutActivity.formatTime(cursor.getInt(4)));
		}
	    });
    }
}
